tox: tox is a generic virtualenv management and test command line tool
======================================================================

Description
-----------

tox is a generic virtualenv management and test command line tool

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/tox/

